<?php

namespace ShineSoftware\Setefi\Gateway\Request;

use Magento\Payment\Gateway\ConfigInterface;
use Magento\Payment\Gateway\Data\PaymentDataObjectInterface;
use Magento\Payment\Gateway\Request\BuilderInterface;
use \Magento\Framework\Encryption\EncryptorInterface;

class AuthorizationRequest implements BuilderInterface {

    private $config;
    public $_storeManager;
    public $_resolver;
    public $_logger;
    protected $_encryptor;

    public function __construct(
    ConfigInterface $config, \Magento\Store\Model\StoreManagerInterface $storeManager, \Magento\Framework\Locale\Resolver $resolver, \ShineSoftware\Setefi\Model\Logger\Shinelogger $logger, EncryptorInterface $encryptor
    ) {
        $this->config = $config;
        $this->_storeManager = $storeManager;
        $this->_resolver = $resolver;
        $this->_logger = $logger;
        $this->_encryptor = $encryptor;
    }

    public function build(array $buildSubject) {
        if (!isset($buildSubject['payment']) || !$buildSubject['payment'] instanceof PaymentDataObjectInterface
        ) {
            throw new \InvalidArgumentException('Payment data object should be provided');
        }
        $payment = $buildSubject['payment'];
        $order = $payment->getOrder();
        $address = $order->getShippingAddress();
        $id = $this->config->getValue('id', $order->getStoreId());
        $encrypted_password = $this->config->getValue('password', $order->getStoreId());
        $password = $this->_encryptor->decrypt($encrypted_password);
        $description = $this->config->getValue('description', $order->getStoreId());
        if ($this->config->getValue('debug', $order->getStoreId()) == 1) {
            $url = $this->config->getValue('urltest', $order->getStoreId());
        } else {
            $url = $this->config->getValue('urllive', $order->getStoreId());
        }
        $data = [
            'url' => $url,
            'id' => $id,
            'password' => $password,
            'operationType' => 'initialize',
            'amount' => number_format($order->getGrandTotalAmount(), 2),
            'currencyCode' => $this->config->getValue('currency', $order->getStoreId()),
            'language' => $this->_resolver->getLocale(),
            'responseToMerchantUrl' => $this->_storeManager->getStore()->getUrl('setefi/hosted/notify', ['_current' => true]),
            'recoveryUrl' => $this->_storeManager->getStore()->getUrl('setefi/hosted/error', ['_current' => true]),
            'merchantOrderId' => $order->getOrderIncrementId(),
            'description' => !empty($description) ? $description : __('Products in my cart'),
            'cardHolderEmail' => $address->getEmail(),
            'customField' => md5($id . $password),
        ];
        $this->_logger->debug(__METHOD__ . " - " . json_encode($data));
        return $data;
    }

}

;
